@@ -1,20 +1,27 @@
-from __future__ import annotations
-
+import sys
+from collections.abc import Sequence
 from pathlib import Path
-from typing import TYPE_CHECKING, Sequence, Union, cast
+from typing import TYPE_CHECKING, Optional, Union, cast
 
 if TYPE_CHECKING:
+    from alembic.migration import MigrationContext
+    from alembic.operations.ops import MigrationScript, UpgradeOps
     from click import Group
 
     from advanced_alchemy.config import SQLAlchemyAsyncConfig, SQLAlchemySyncConfig
-    from alembic.migration import MigrationContext
-    from alembic.operations.ops import MigrationScript, UpgradeOps
 
 __all__ = ("add_migration_commands", "get_alchemy_group")
 
 
-def get_alchemy_group() -> Group:
-    """Get the Advanced Alchemy CLI group."""
+def get_alchemy_group() -> "Group":
+    """Get the Advanced Alchemy CLI group.
+
+    Raises:
+        MissingDependencyError: If the `click` package is not installed.
+
+    Returns:
+        The Advanced Alchemy CLI group.
+    """
     from advanced_alchemy.exceptions import MissingDependencyError
 
     try:
@@ -33,14 +40,22 @@ def get_alchemy_group() -> Group:
         type=str,
     )
     @click.pass_context
-    def alchemy_group(ctx: click.Context, config: str) -> None:
+    def alchemy_group(ctx: "click.Context", config: str) -> None:
         """Advanced Alchemy CLI commands."""
+        from pathlib import Path
+
         from rich import get_console
 
         from advanced_alchemy.utils import module_loader
 
         console = get_console()
         ctx.ensure_object(dict)
+
+        # Add current working directory to sys.path to allow loading local config modules
+        cwd = str(Path.cwd())
+        if cwd not in sys.path:
+            sys.path.insert(0, cwd)
+
         try:
             config_instance = module_loader.import_string(config)
             if isinstance(config_instance, Sequence):
@@ -50,12 +65,26 @@ def get_alchemy_group() -> Group:
         except ImportError as e:
             console.print(f"[red]Error loading config: {e}[/]")
             ctx.exit(1)
+        finally:
+            # Clean up: remove the cwd from sys.path if we added it
+            if cwd in sys.path and sys.path[0] == cwd:
+                sys.path.remove(cwd)
 
     return alchemy_group
 
 
-def add_migration_commands(database_group: Group | None = None) -> Group:  # noqa: C901, PLR0915
-    """Add migration commands to the database group."""
+def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":  # noqa: C901, PLR0915
+    """Add migration commands to the database group.
+
+    Args:
+        database_group: The database group to add the commands to.
+
+    Raises:
+        MissingDependencyError: If the `click` package is not installed.
+
+    Returns:
+        The database group with the migration commands added.
+    """
     from advanced_alchemy.exceptions import MissingDependencyError
 
     try:
@@ -96,9 +125,17 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
     )
 
     def get_config_by_bind_key(
-        ctx: click.Context, bind_key: str | None
-    ) -> SQLAlchemyAsyncConfig | SQLAlchemySyncConfig:
-        """Get the SQLAlchemy config for the specified bind key."""
+        ctx: "click.Context", bind_key: Optional[str]
+    ) -> "Union[SQLAlchemyAsyncConfig, SQLAlchemySyncConfig]":
+        """Get the SQLAlchemy config for the specified bind key.
+
+        Args:
+            ctx: The click context.
+            bind_key: The bind key to get the config for.
+
+        Returns:
+            The SQLAlchemy config for the specified bind key.
+        """
         configs = ctx.obj["configs"]
         if bind_key is None:
             return cast("Union[SQLAlchemyAsyncConfig, SQLAlchemySyncConfig]", configs[0])
@@ -108,7 +145,7 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
                 return cast("Union[SQLAlchemyAsyncConfig, SQLAlchemySyncConfig]", config)
 
         console.print(f"[red]No config found for bind key: {bind_key}[/]")
-        ctx.exit(1)  # noqa: RET503
+        sys.exit(1)
 
     @database_group.command(
         name="show-current-revision",
@@ -116,11 +153,11 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
     )
     @bind_key_option
     @verbose_option
-    def show_database_revision(bind_key: str | None, verbose: bool) -> None:  # pyright: ignore[reportUnusedFunction]
+    def show_database_revision(bind_key: Optional[str], verbose: bool) -> None:  # pyright: ignore[reportUnusedFunction]
         """Show current database revision."""
         from advanced_alchemy.alembic.commands import AlembicCommands
 
-        ctx = click.get_current_context()
+        ctx = cast("click.Context", click.get_current_context())
         console.rule("[yellow]Listing current revision[/]", align="left")
         sqlalchemy_config = get_config_by_bind_key(ctx, bind_key)
         alembic_commands = AlembicCommands(sqlalchemy_config=sqlalchemy_config)
@@ -145,14 +182,14 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
         default="-1",
     )
     def downgrade_database(  # pyright: ignore[reportUnusedFunction]
-        bind_key: str | None, revision: str, sql: bool, tag: str | None, no_prompt: bool
+        bind_key: Optional[str], revision: str, sql: bool, tag: Optional[str], no_prompt: bool
     ) -> None:
         """Downgrade the database to the latest revision."""
         from rich.prompt import Confirm
 
         from advanced_alchemy.alembic.commands import AlembicCommands
 
-        ctx = click.get_current_context()
+        ctx = cast("click.Context", click.get_current_context())
         console.rule("[yellow]Starting database downgrade process[/]", align="left")
         input_confirmed = (
             True
@@ -183,14 +220,14 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
         default="head",
     )
     def upgrade_database(  # pyright: ignore[reportUnusedFunction]
-        bind_key: str | None, revision: str, sql: bool, tag: str | None, no_prompt: bool
+        bind_key: Optional[str], revision: str, sql: bool, tag: Optional[str], no_prompt: bool
     ) -> None:
         """Upgrade the database to the latest revision."""
         from rich.prompt import Confirm
 
         from advanced_alchemy.alembic.commands import AlembicCommands
 
-        ctx = click.get_current_context()
+        ctx = cast("click.Context", click.get_current_context())
         console.rule("[yellow]Starting database upgrade process[/]", align="left")
         input_confirmed = (
             True
@@ -202,6 +239,20 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
             alembic_commands = AlembicCommands(sqlalchemy_config=sqlalchemy_config)
             alembic_commands.upgrade(revision=revision, sql=sql, tag=tag)
 
+    @database_group.command(
+        help="Stamp the revision table with the given revision",
+    )
+    @click.argument("revision", type=str)
+    @bind_key_option
+    def stamp(bind_key: Optional[str], revision: str) -> None:  # pyright: ignore[reportUnusedFunction]
+        """Stamp the revision table with the given revision."""
+        from advanced_alchemy.alembic.commands import AlembicCommands
+
+        ctx = cast("click.Context", click.get_current_context())
+        sqlalchemy_config = get_config_by_bind_key(ctx, bind_key)
+        alembic_commands = AlembicCommands(sqlalchemy_config=sqlalchemy_config)
+        alembic_commands.stamp(revision=revision)
+
     @database_group.command(
         name="init",
         help="Initialize migrations for the project.",
@@ -216,14 +267,14 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
     @click.option("--package", is_flag=True, default=True, help="Create `__init__.py` for created folder")
     @no_prompt_option
     def init_alembic(  # pyright: ignore[reportUnusedFunction]
-        bind_key: str | None, directory: str | None, multidb: bool, package: bool, no_prompt: bool
+        bind_key: Optional[str], directory: Optional[str], multidb: bool, package: bool, no_prompt: bool
     ) -> None:
         """Initialize the database migrations."""
         from rich.prompt import Confirm
 
         from advanced_alchemy.alembic.commands import AlembicCommands
 
-        ctx = click.get_current_context()
+        ctx = cast("click.Context", click.get_current_context())
         console.rule("[yellow]Initializing database migrations.", align="left")
         input_confirmed = (
             True if no_prompt else Confirm.ask("[bold]Are you sure you want initialize migrations for the project?[/]")
@@ -254,15 +305,15 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
     @click.option("--rev-id", default=None, help="Specify a ID to use for revision.")
     @no_prompt_option
     def create_revision(  # pyright: ignore[reportUnusedFunction]
-        bind_key: str | None,
-        message: str | None,
+        bind_key: Optional[str],
+        message: Optional[str],
         autogenerate: bool,
         sql: bool,
         head: str,
         splice: bool,
-        branch_label: str | None,
-        version_path: str | None,
-        rev_id: str | None,
+        branch_label: Optional[str],
+        version_path: Optional[str],
+        rev_id: Optional[str],
         no_prompt: bool,
     ) -> None:
         """Create a new database revision."""
@@ -271,9 +322,9 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
         from advanced_alchemy.alembic.commands import AlembicCommands
 
         def process_revision_directives(
-            context: MigrationContext,  # noqa: ARG001
+            context: "MigrationContext",  # noqa: ARG001
             revision: tuple[str],  # noqa: ARG001
-            directives: list[MigrationScript],
+            directives: list["MigrationScript"],
         ) -> None:
             """Handle revision directives."""
             if autogenerate and cast("UpgradeOps", directives[0].upgrade_ops).is_empty():
@@ -294,7 +345,7 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
                 )
                 directives.clear()
 
-        ctx = click.get_current_context()
+        ctx = cast("click.Context", click.get_current_context())
         console.rule("[yellow]Starting database upgrade process[/]", align="left")
         if message is None:
             message = "autogenerated" if no_prompt else Prompt.ask("Please enter a message describing this revision")
@@ -316,7 +367,7 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
     @database_group.command(name="drop-all", help="Drop all tables from the database.")
     @bind_key_option
     @no_prompt_option
-    def drop_all(bind_key: str | None, no_prompt: bool) -> None:  # pyright: ignore[reportUnusedFunction]
+    def drop_all(bind_key: Optional[str], no_prompt: bool) -> None:  # pyright: ignore[reportUnusedFunction]
         """Drop all tables from the database."""
         from anyio import run
         from rich.prompt import Confirm
@@ -324,14 +375,14 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
         from advanced_alchemy.alembic.utils import drop_all
         from advanced_alchemy.base import metadata_registry
 
-        ctx = click.get_current_context()
+        ctx = cast("click.Context", click.get_current_context())
         console.rule("[yellow]Dropping all tables from the database[/]", align="left")
         input_confirmed = no_prompt or Confirm.ask(
             "[bold red]Are you sure you want to drop all tables from the database?"
         )
 
         async def _drop_all(
-            configs: Sequence[SQLAlchemyAsyncConfig | SQLAlchemySyncConfig],
+            configs: "Sequence[Union[SQLAlchemyAsyncConfig, SQLAlchemySyncConfig]]",
         ) -> None:
             for config in configs:
                 engine = config.get_engine()
@@ -359,7 +410,7 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
         default=Path.cwd() / "fixtures",
         required=False,
     )
-    def dump_table_data(bind_key: str | None, table_names: tuple[str, ...], dump_dir: Path) -> None:  # pyright: ignore[reportUnusedFunction]
+    def dump_table_data(bind_key: Optional[str], table_names: tuple[str, ...], dump_dir: Path) -> None:  # pyright: ignore[reportUnusedFunction]
         """Dump table data to JSON files."""
         from anyio import run
         from rich.prompt import Confirm
@@ -367,7 +418,7 @@ def add_migration_commands(database_group: Group | None = None) -> Group:  # noq
         from advanced_alchemy.alembic.utils import dump_tables
         from advanced_alchemy.base import metadata_registry, orm_registry
 
-        ctx = click.get_current_context()
+        ctx = cast("click.Context", click.get_current_context())
         all_tables = "*" in table_names
 
         if all_tables and not Confirm.ask(
